@@ -28,7 +28,6 @@
 #include <stdio.h>
 
 #include "ati.h"
-#include "atiadjust.h"
 #include "atiaudio.h"
 #include "atibus.h"
 #include "atichip.h"
@@ -50,6 +49,7 @@
 #include "atividmem.h"
 #include "atiwonderio.h"
 #include "atixv.h"
+#include "atiadjust.h"
 
 #include "vbe.h"
 #if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
@@ -531,9 +531,8 @@ ATIPreInit
 
 #ifndef AVOID_CPIO
 
-    xf86Int10InfoPtr pInt10Info = NULL;
     vbeInfoPtr       pVBE = NULL;
-    pointer          pInt10Module, pDDCModule = NULL, pVBEModule = NULL;
+    pointer          pVBEModule = NULL;
 
 #endif /* AVOID_CPIO */
 
@@ -560,7 +559,7 @@ ATIPreInit
     pATI->Chip = pEntity->chipset;
     pVideo = xf86GetPciInfoForEntity(pATI->iEntity);
 
-    xfree(pEntity);
+    free(pEntity);
 
 #ifndef XSERVER_LIBPCIACCESS
     if (!pResources)
@@ -657,42 +656,21 @@ ATIPreInit
 #endif /* TV_OUT */
 
     /*
-     * If there is an ix86-style BIOS, ensure its initialisation entry point
-     * has been executed, and retrieve DDC and VBE information from it.
+     * If VBE setup works, grab DDC from it
      */
-    if (!(pInt10Module = xf86LoadSubModule(pScreenInfo, "int10")))
-    {
-        xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
-            "Unable to load int10 module.\n");
-    }
-    else if (!(pInt10Info = xf86InitInt10(pATI->iEntity)))
-    {
-        xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
-             "Unable to initialise int10 interface.\n");
+    if (!(pVBEModule = xf86LoadSubModule(pScreenInfo, "vbe"))) {
+	xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
+		   "Unable to load vbe module.\n");
     }
     else
     {
-        if (!(pDDCModule = xf86LoadSubModule(pScreenInfo, "ddc")))
-        {
-            xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
-                "Unable to load ddc module.\n");
-        }
-        else
-        if (!(pVBEModule = xf86LoadSubModule(pScreenInfo, "vbe")))
-        {
-            xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
-                "Unable to load vbe module.\n");
-        }
-        else
-        {
-            if ((pVBE = VBEInit(pInt10Info, pATI->iEntity)))
-            {
-                ConfiguredMonitor = vbeDoEDID(pVBE, pDDCModule);
-            }
-        }
+	if ((pVBE = VBEInit(NULL, pATI->iEntity)))
+	    ConfiguredMonitor = vbeDoEDID(pVBE, NULL);
 
-        if (!(flags & PROBE_DETECT))
+        if (pVBE && !(flags & PROBE_DETECT))
         {
+	    xf86Int10InfoPtr pInt10Info = pVBE->pInt10;
+
             /* Validate, then make a private copy of, the initialised BIOS */
             CARD8 *pBIOS = xf86int10Addr(pInt10Info, pInt10Info->BIOSseg << 4);
 
@@ -715,15 +693,9 @@ ATIPreInit
     /* De-activate VBE */
     vbeFree(pVBE);
     xf86UnloadSubModule(pVBEModule);
-
-    /* De-activate int10 */
-    xf86FreeInt10(pInt10Info);
-    xf86UnloadSubModule(pInt10Module);
 #else
-    pATI->pInt10 = pInt10Info;
     pATI->pVBE = pVBE;
     pVBE = NULL;
-    pInt10Info = NULL;
 #endif /* TV_OUT */
 
     if (ConfiguredMonitor && !(flags & PROBE_DETECT))
@@ -732,9 +704,6 @@ ATIPreInit
         xf86SetDDCproperties(pScreenInfo, ConfiguredMonitor);
     }
 
-    /* DDC module is no longer needed at this point */
-    xf86UnloadSubModule(pDDCModule);
-
 #endif /* AVOID_CPIO */
 
     if (flags & PROBE_DETECT)
@@ -1110,12 +1079,14 @@ ATIPreInit
         }
     }
 
+#ifndef XSERVER_LIBPCIACCESS
     if (!xf86LinearVidMem())
     {
         xf86DrvMsg(pScreenInfo->scrnIndex, X_ERROR,
             "A linear aperture is not available.\n");
         goto bail;
     }
+#endif
 
     /*
      * Set colour weights.
@@ -2281,8 +2252,6 @@ ATIPreInit
 
     pitchInc = minPitch * pATI->bitsPerPixel;
 
-    pScreenInfo->maxHValue = (MaxBits(CRTC_H_TOTAL) + 1) << 3;
-
     if (pATI->Chip < ATI_CHIP_264VT)
     {
         /*
@@ -2293,12 +2262,8 @@ ATIPreInit
          */
         ATIClockRange.doubleScanAllowed = FALSE;
 
-        /* CRTC_H_TOTAL is one bit narrower */
-        pScreenInfo->maxHValue >>= 1;
     }
 
-    pScreenInfo->maxVValue = MaxBits(CRTC_V_TOTAL) + 1;
-
     maxPitch = minPitch * MaxBits(CRTC_PITCH);
 
     if (pATI->OptionAccel)
